@@ -35,11 +35,10 @@ also commented @EXPORT=();
     
 =cut 
 
-use strict;
-use warnings;
+use Moose;
+our $VERSION = '1.0.0';
 use Exporter;  # Gain export capability
 #use vars qw(@ISA @EXPORT @EXPORT_OK );    # pacify strict
-our $VERSION = '1.0.0';
 
 =head2 declare
 
@@ -76,6 +75,7 @@ our (@EXPORT_OK, @ISA); #Global variables
   $ibot_mute_check_pickfile $ibot_mute_check_pickfile_ $ibot_mute_xfile_picks $ibot_mute_tfile_picks
   $temp_single_gather_par_file_mute  
   $temp 
+  $fldr
   $ivpicks_sorted_par_
   $ms2s $us2s
   $offset 
@@ -349,6 +349,7 @@ our $cdp    = 'cdp';
 our $CDP   = 'CDP';
 our $SP     = 'SP';
 our $ep     = 'ep';
+our $fldr   = 'fldr';
 our $day    = 'day';
 our $gx     = 'gx';
 our $hour   = 'hour';
