@@ -41,7 +41,6 @@ package App::SeismicUnixGui::misc::big_streams_param;
 =cut
 
 use Moose;
-
 our $VERSION = '0.0.3';
 
 use aliased 'App::SeismicUnixGui::misc::L_SU_global_constants';
@@ -782,7 +781,7 @@ sub my_length {
 	}
 	else {
 
-		# print ("big_streams_param,my_length, empty names array reference\n");
+		print ("big_streams_param,my_length, empty names array reference\n");
 	}
 
 }
